/*
 *  Copyright (c) xsocket.org, 2006 - 2008. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xsocket.org/
 */
package org.xsocket.connection.http;

import java.io.IOException;
import java.nio.BufferUnderflowException;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.xsocket.MaxReadSizeExceededException;
import org.xsocket.connection.IDataHandler;
import org.xsocket.connection.IDisconnectHandler;
import org.xsocket.connection.INonBlockingConnection;




/**
 * 
 * @author grro@xsocket.org
 */
abstract class AbstractBodyParser implements IDataHandler, IDisconnectHandler {

	
	private static final Logger LOG = Logger.getLogger(AbstractBodyParser.class.getName());
	
	private AbstractHttpConnection httpConnection = null;
	private NonBlockingBodyDataSource dataSource = null;
	

	public AbstractBodyParser(AbstractHttpConnection httpConnection, NonBlockingBodyDataSource dataSource) throws IOException {
		this.httpConnection = httpConnection;
		this.dataSource = dataSource;
		
		httpConnection.setBodyParser(this);
	}

	
	abstract boolean isReceiving();
	

	abstract void parseBody(INonBlockingConnection connection, NonBlockingBodyDataSource dataSource) throws IOException;
	
	
	public final boolean onData(INonBlockingConnection connection) throws IOException, BufferUnderflowException, MaxReadSizeExceededException {		
		httpConnection.onBodyDataReceived();
		
		if (isReceiving()) {
			
			try {
				parseBody(connection, dataSource);
				
			} catch (BufferUnderflowException bue) {
				throw bue;
				
			} catch (IOException ioe) {
				if (LOG.isLoggable(Level.FINE)) {
					LOG.fine("[" + httpConnection.getId() + "] (protocol?) error occured by reading body " + ioe.toString());
				}
		
				httpConnection.destroy();
				dataSource.setIOException(ioe);
				dataSource.close();
			}
		} 
		
		return true;
	}
	
	final void setComplete() {
		httpConnection.removeBodyParser();
		dataSource.setComplete(true);
	}

	public boolean onDisconnect(INonBlockingConnection connection) throws IOException {
		
		if (isReceiving()) {
			dataSource.setIOException(new IOException("protocol error occured (connection is closed, but more data is expected). May be connection has been closed by peer?"));
		}
		
		dataSource.onDisconnect();

		return true;
	}
}
