/*
 *  Copyright (c) xsocket.org, 2006 - 2008. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xsocket.org/
 */
package org.xsocket.connection.http;

import java.io.IOException;
import java.nio.BufferUnderflowException;
import java.nio.ByteBuffer;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.xsocket.MaxReadSizeExceededException;
import org.xsocket.connection.INonBlockingConnection;




/**
 * 
 * @author grro@xsocket.org
 */
final class BoundBodyParser extends AbstractBodyParser {

	
	private static final Logger LOG = Logger.getLogger(BoundBodyParser.class.getName());
	
	private int size = 0;
	private int remaining = 0;
		
	
	public BoundBodyParser(AbstractHttpConnection httpConnection, IHttpHeader header, NonBlockingBodyDataSource dataSource) throws IOException {
		super(httpConnection, dataSource);
		
		size = header.getContentLength();
		remaining = size;
	}

	
	@Override
	boolean isReceiving() {
		return (remaining > 0);
	}
	
	
	
	
	void parseBody(INonBlockingConnection connection, NonBlockingBodyDataSource dataSource) throws IOException, BufferUnderflowException, MaxReadSizeExceededException {			

		int available = connection.available();
		
		if (available == 0) {
			return;
		}
		

				
		// not enough data
		if (available < remaining) {
			ByteBuffer[] data = connection.readByteBufferByLength(available);
			remaining -= available;
			
			dataSource.append(data);

			if (LOG.isLoggable(Level.FINE)) {
				LOG.fine("[" + connection.getId() + "] " + available + " bytes read remaining=" + remaining);
			}

			
		// enough data 
		} else {
			if (LOG.isLoggable(Level.FINE)) {
				LOG.fine("[" + connection.getId() + "] reading remaining data " + remaining);
			}
			
			ByteBuffer[] data = connection.readByteBufferByLength(remaining);
			remaining = 0;
			
			dataSource.append(data);
		} 

		if (remaining == 0) {
			if (LOG.isLoggable(Level.FINE)) {
				LOG.fine("[" + connection.getId() + "] complete body received (size=" + size + ")");
			}
			
			setComplete();
			
		} else {
			if (LOG.isLoggable(Level.FINER)) {
				LOG.finer("[" + connection.getId() + "] body data read. wating for more data");
			}

		}
	}
}
