/*
 *  Copyright (c) xsocket.org, 2006 - 2008. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xsocket.org/
 */
package org.xsocket.connection.http;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.xsocket.connection.INonBlockingConnection;




/**
 * 
 * @author grro@xsocket.org
 */
final class ConnectionTerminatedBodyParser extends AbstractBodyParser {

	
	private static final Logger LOG = Logger.getLogger(ConnectionTerminatedBodyParser.class.getName());
	private int received = 0;
	
	private boolean isReceiving = true;
	
	
	/**
	 * constructor
	 * 
	 * @param httpConnection   the http connection
	 * @param header           the message header
	 * @param encoding         the encoding to use
	 */
	public ConnectionTerminatedBodyParser(AbstractHttpConnection httpConnection, NonBlockingBodyDataSource dataSource) throws IOException {
		super(httpConnection, dataSource);
	}


	@Override
	boolean isReceiving() {
		return isReceiving;
	}

	
	@Override
	void parseBody(INonBlockingConnection connection, NonBlockingBodyDataSource dataSource) throws IOException {
		
		int available = connection.available();
		
		if (available > 0) {
			dataSource.append(connection.readByteBufferByLength(available));
			received += available;
			
			if (LOG.isLoggable(Level.FINE)) {
				LOG.fine("[" + connection.getId() + "] received data (total received = " + received + " bytes)");
			}	
		}
	}
	
	
	public boolean onDisconnect(INonBlockingConnection connection) throws IOException {		
		isReceiving = false;
		setComplete();
		
		return super.onDisconnect(connection);
	}
}
