/*
 *  Copyright (c) xsocket.org, 2006 - 2008. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xsocket.org/
 */
package org.xsocket.connection.http;


import java.io.IOException;
import java.nio.channels.ClosedChannelException;
import java.util.concurrent.Executor;

import org.xsocket.connection.IConnection;



/**
 * A http connection (session) between two http client and http server.<br><br>
 *
 *
 * @author grro@xsocket.org
 */
public interface IHttpConnection extends IConnection {
	

	/**
	 * returns if the connection is persistent 
	 * 
	 * @return true, if connection is persistent
	 */
	public boolean isPersistent();
	
	
	/**
	 * ad hoc activation of a secured mode (SSL). By performing of this
	 * method all remaining data to send will be flushed.
	 * After this all data will be sent and received in the secured mode
	 *
	 * @throws IOException If some other I/O error occurs
	 */
	public void activateSecuredMode() throws IOException;
	

	/**
	 * returns if the connection is in secured mode
	 * @return true, if the connection is in secured mode
	 */
	public boolean isSecure();
	
	
	public void setFlushmode(FlushMode flushmode);
	
	/**
	 * set the max app read buffer threshold
	 * @param maxSize the max read buffer threshold
	 */
	public void setMaxReadBufferThreshold(int size);
	
	
	/**
	 * get the max app read buffer size. If the read buffer size exceeds this limit the 
	 * connection will stop receiving data. The read buffer size can be higher the limit  
	 * (max size = maxReadBufferThreshold + socket read buffer size  * 2)
	 * 
	 * @return the max read buffer threshold
	 */
	public int getMaxReadBufferThreshold();
		
	
	
	public void setWriteTransferRate(int bytesPerSecond) throws ClosedChannelException, IOException;
	
	
	public Executor getWorkerpool();
}
