/*
 *  Copyright (c) xsocket.org, 2006 - 2008. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xsocket.org/
 */
package org.xsocket.connection.http;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;





/**
 * Annotation which defines when a call back method will be call. Either by 
 * receiving a message header (default) or by receiving the complete message. 
 * This annotation can be used to declare the desired invoke modus by performing 
 * call back method such as <code>onRequest</code> or <code>onResponse</code>. 
 * For these call back method xSocket is free to invoke the method on MessageRecevied 
 * even though on HeaderReceived is declared. 
 * 
 * E.g.
 * <pre>
 *   class MyResponseHandler implements IHttpResponseHandler {
 *   
 *      &#064InvokeOn(InvokeOn.MESSAGE_RECEIVED)   // default is header received
 *      public void onResponse(IHttpResponse response) throws IOException {
 *      
 *      }
 *
 *      ...      
 *   }
 * </pre>  
 * 
 * 
 * @author grro@xsocket.org
 */
@Target({ElementType.TYPE, ElementType.METHOD})
@Retention(RetentionPolicy.RUNTIME)
public @interface InvokeOn {
	
	public static final int HEADER_RECEIVED = 0;
	public static final int MESSAGE_RECEIVED = 1;
	
	int value() default HEADER_RECEIVED;
}
