/*
 *  Copyright (c) xsocket.org, 2006 - 2008. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xsocket.org/
 */
package org.xsocket.connection.http;

import java.io.IOException;
import java.nio.ByteBuffer;




/**
 *  
 * @author grro@xsocket.org
 */
final class LocalBodyWriter implements IBodyWriter {
	
	private ITarget forwardTarget = null;
	
	public LocalBodyWriter(ITarget forwardTarget) {
		this.forwardTarget = forwardTarget;
	}
	
	public void flush(ByteBuffer[] bodyData) throws IOException {
		forwardTarget.append(bodyData);
	}
	
	
	public void close() throws IOException {
		forwardTarget.setComplete();
	}
	
	public void destroy() {
		forwardTarget.destroy();
	}
	
	
	static interface ITarget {
		
		public void append(ByteBuffer[] bodyData) throws IOException;
		
		public void setComplete() throws IOException;
		
		public void destroy();
	}
}